pub struct InputMapper { /* private fields */ }Expand description
Maps raw browser input events to application actions based on the current interaction mode.
Implementations
Sourceimpl InputMapper
impl InputMapper
pub fn set_mode(&mut self, mode: InteractionMode)
Sourcepub fn process(&mut self, event: &InputEvent) -> Vec<AppAction>
pub fn process(&mut self, event: &InputEvent) -> Vec<AppAction>
Process a raw input event and return zero or more application actions.